@@ -5,18 +5,17 @@ from itertools import repeat
 from textwrap import dedent
 from typing import TYPE_CHECKING, Callable, Tuple
 
-from anytree.iterators import LevelOrderIter
 from xarray import DataArray, Dataset
 
-from .treenode import TreeNode
-from .utils import removeprefix, removesuffix
+from .iterators import LevelOrderIter
+from .treenode import NodePath, TreeNode
 
 if TYPE_CHECKING:
     from .datatree import DataTree
 
 
 class TreeIsomorphismError(ValueError):
-    """Error raised if two tree objects are not isomorphic to one another when they need to be."""
+    """Error raised if two tree objects do not share the same node structure."""
 
     pass
 
@@ -24,8 +23,8 @@ class TreeIsomorphismError(ValueError):
 def check_isomorphic(
     a: DataTree,
     b: DataTree,
-    require_names_equal=False,
-    check_from_root=True,
+    require_names_equal: bool = False,
+    check_from_root: bool = True,
 ):
     """
     Check that two trees have the same structure, raising an error if not.
@@ -82,7 +81,7 @@ def diff_treestructure(a: DataTree, b: DataTree, require_names_equal: bool) -> s
     # Checking for isomorphism by walking in this way implicitly assumes that the tree is an ordered tree
     # (which it is so long as children are stored in a tuple or list rather than in a set).
     for node_a, node_b in zip(LevelOrderIter(a), LevelOrderIter(b)):
-        path_a, path_b = node_a.pathstr, node_b.pathstr
+        path_a, path_b = node_a.path, node_b.path
 
         if require_names_equal:
             if node_a.name != node_b.name:
@@ -104,7 +103,7 @@ def diff_treestructure(a: DataTree, b: DataTree, require_names_equal: bool) -> s
     return ""
 
 
-def map_over_subtree(func: Callable) -> DataTree | Tuple[DataTree, ...]:
+def map_over_subtree(func: Callable) -> Callable:
     """
     Decorator which turns a function which acts on (and returns) Datasets into one which acts on and returns DataTrees.
 
@@ -154,7 +153,7 @@ def map_over_subtree(func: Callable) -> DataTree | Tuple[DataTree, ...]:
     # TODO inspect function to work out immediately if the wrong number of arguments were passed for it?
 
     @functools.wraps(func)
-    def _map_over_subtree(*args, **kwargs):
+    def _map_over_subtree(*args, **kwargs) -> DataTree | Tuple[DataTree, ...]:
         """Internal function which maps func over every node in tree, returning a tree of the results."""
         from .datatree import DataTree
 
@@ -190,10 +189,10 @@ def map_over_subtree(func: Callable) -> DataTree | Tuple[DataTree, ...]:
             *args_as_tree_length_iterables,
             *list(kwargs_as_tree_length_iterables.values()),
         ):
-            node_args_as_datasets = [
+            node_args_as_datasetviews = [
                 a.ds if isinstance(a, DataTree) else a for a in all_node_args[:n_args]
             ]
-            node_kwargs_as_datasets = dict(
+            node_kwargs_as_datasetviews = dict(
                 zip(
                     [k for k in kwargs_as_tree_length_iterables.keys()],
                     [
@@ -205,25 +204,24 @@ def map_over_subtree(func: Callable) -> DataTree | Tuple[DataTree, ...]:
 
             # Now we can call func on the data in this particular set of corresponding nodes
             results = (
-                func(*node_args_as_datasets, **node_kwargs_as_datasets)
-                if node_of_first_tree.has_data
+                func(*node_args_as_datasetviews, **node_kwargs_as_datasetviews)
+                if not node_of_first_tree.is_empty
                 else None
             )
 
             # TODO implement mapping over multiple trees in-place using if conditions from here on?
-            out_data_objects[node_of_first_tree.pathstr] = results
+            out_data_objects[node_of_first_tree.path] = results
 
         # Find out how many return values we received
         num_return_values = _check_all_return_values(out_data_objects)
 
-        ancestors_of_new_root = removesuffix(first_tree.pathstr, first_tree.name)
-
         # Reconstruct 1+ subtrees from the dict of results, by filling in all nodes of all result trees
+        original_root_path = first_tree.path
         result_trees = []
         for i in range(num_return_values):
             out_tree_contents = {}
             for n in first_tree.subtree:
-                p = n.pathstr
+                p = n.path
                 if p in out_data_objects.keys():
                     if isinstance(out_data_objects[p], tuple):
                         output_node_data = out_data_objects[p][i]
@@ -233,12 +231,13 @@ def map_over_subtree(func: Callable) -> DataTree | Tuple[DataTree, ...]:
                     output_node_data = None
 
                 # Discard parentage so that new trees don't include parents of input nodes
-                # TODO use a proper relative_path method on DataTree(/TreeNode) to do this
-                relative_path = removeprefix(p, ancestors_of_new_root)
+                relative_path = str(NodePath(p).relative_to(original_root_path))
+                relative_path = "/" if relative_path == "." else relative_path
                 out_tree_contents[relative_path] = output_node_data
 
             new_tree = DataTree.from_dict(
-                name=first_tree.name, data_objects=out_tree_contents
+                out_tree_contents,
+                name=first_tree.name,
             )
             result_trees.append(new_tree)
 
